import React, { useEffect, useState, useRef } from "react";
import ms from "pretty-ms";

const useCountdown = (seconds, onEnd) => {
  const [finished, setFinished] = useState(false);
  const [remaining, setRemaining] = useState(seconds);
  const remainingMut = useRef(seconds);

  useEffect(() => {
    const timer = setInterval(() => setRemaining(remainingMut.current -= 1), 1000);
    return () => clearInterval(timer);
  }, []);

  useEffect(() => {
    if (!finished && remaining <= 0) {
      onEnd();
      setFinished(true);
    }
  }, [finished, remaining, onEnd])

  return remaining;
}

export default ({ seconds, onTimeout }) => {
  const remaining = useCountdown(seconds, onTimeout);

  return remaining > 0 
    ? <span className="timer">Time: <span className="timer__time">{ms(remaining * 1000)}</span></span> 
    : <span className="timer timer--timeout">Time's up!</span>
}
